@@ -9,9 +9,11 @@ OC.L10N.register(
     "Missing a temporary folder" : "Адсутнічае часовая папка",
     "Could not write file to disk" : "Не ўдалося запісаць файл на дыск",
     "A PHP extension stopped the file upload" : "Пашырэнне PHP спыніла запампоўванне файла",
+    "No file uploaded or file size exceeds maximum of %s" : "Файл не запампаваны, або памер файла перавышае максімальны %s",
     "copy" : "копія",
     "Done" : "Гатова",
     "File" : "Файл",
+    "Invalid date, date format must be YYYY-MM-DD" : "Памылковая дата, дата павінна быць у фармаце ГГГГ-ММ-ДД",
     "Cancel" : "Скасаваць",
     "Drop your files to upload" : "Перацягніце файлы для запампоўвання",
     "File already exists" : "Файл ужо існуе",
@@ -50,6 +52,7 @@ OC.L10N.register(
     "Reply" : "Адказаць",
     "Update" : "Абнавіць",
     "Description" : "Апісанне",
+    "Formatting help" : "Даведка па фармаціраванні",
     "Later today – {timeLocale}" : "Пазней сёння – {timeLocale}",
     "Set due date for later today" : "Задаць дату выканання на пазней сёння",
     "Tomorrow – {timeLocale}" : "Заўтра – {timeLocale}",
@@ -59,6 +62,7 @@ OC.L10N.register(
     "Set due date for next week" : "Задаць дату выканання на наступны тыдзень",
     "Create a new tag:" : "Стварыць новы тэг:",
     "(group)" : "(група)",
+    "Todo items" : "Элементы спісу задач",
     "Open link" : "Адкрыць спасылку",
     "Edit title" : "Рэдагаваць загаловак",
     "seconds ago" : "с таму",
@@ -66,12 +70,14 @@ OC.L10N.register(
     "Keyboard shortcut" : "Спалучэнне клавіш",
     "Action" : "Дзеянне",
     "Shift" : "Shift",
+    "Ctrl" : "Ctrl",
     "Search" : "Пошук",
     "Enter" : "Enter",
     "Shared with you" : "Абагулена з вамі",
     "Cancel edit" : "Скасаваць рэдагаванне",
     "An error occurred" : "Узнікла памылка",
     "No notifications" : "Няма апавяшчэнняў",
+    "Export as CSV" : "Экспарт у CSV",
     "Export" : "Экспарт",
     "No results found" : "Вынікаў не знойдзена",
     "{stack} in {board}" : "{stack} у {board}",
@@ -80,6 +86,9 @@ OC.L10N.register(
     "Failed to upload {name}" : "Не ўдалося запампаваць {name}",
     "Share" : "Абагуліць",
     "Personal" : "Асабістыя",
+    "Example Task 3" : "Прыклад задання 3",
+    "Example Task 2" : "Прыклад задання 2",
+    "Example Task 1" : "Прыклад задання 1",
     "Today" : "Сёння",
     "Tomorrow" : "Заўтра"
 },
