@@ -29,6 +29,11 @@ OC.L10N.register(
     "{user} has deleted card {card} in list {stack} on board {board}" : "{user} har slettet kortet {card} i listen {stack} på tavlen {board}",
     "You have renamed the card {before} to {card}" : "Du har omdøbt kortet {before} til {card}",
     "{user} has renamed the card {before} to {card}" : "{user} har omdøbt kortet {before} til {card}",
+    "You have added a description to card {card} in list {stack} on board {board}" : "Du har tilføjet en beskrivelse til kortet {card} i listen {stack} på tavlen {board}",
+    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} har tilføjet en beskrivelse til kortet {card} i listen {stack} på tavlen {board}",
+    "You have updated the description of card {card} in list {stack} on board {board}" : "Du har opdateret beskrivelsen for kortet {card} i listen {stack} på tavlen {board}",
+    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} har opdateret beskrivelsen for kortet {card} i listen {stack} på tavlen {board}",
+    "You have archived card {card} in list {stack} on board {board}" : "Du har arkiveret kortet {card} i listen {stack} på tavlen {board}",
     "Deck" : "Opslag",
     "Changes in the <strong>Deck app</strong>" : "Ændringer i <strong>Opslags app'en</strong>",
     "The file was uploaded" : "Filen blev uploadet",
@@ -44,15 +49,15 @@ OC.L10N.register(
     "Load more" : "Hent flere",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortet \"%s\" på \"%s\" er blevet tildelt dig af %s.",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} har tilknyttet kortet {deck-card} på {deck-board} til dig.",
-    "The card \"%s\" on \"%s\" has reached its due date." : "Kortet \"%s\" på \"%s\" har nået sin forfaldsdato.",
     "The card {deck-card} on {deck-board} has reached its due date." : "Kortet {deck-card} på {deck-board} har nået sin forfaldsdato.",
-    "%s has mentioned you in a comment on \"%s\"." : " %s har nævnt dig i en kommentar på \"%s\".",
-    "{user} has mentioned you in a comment on {deck-card}." : "{user} har nævnt dig i en kommentar på {deck-card}.",
+    "%s has mentioned you in a comment on \"%s\"." : " %s har omtalt dig i en kommentar på \"%s\".",
+    "{user} has mentioned you in a comment on {deck-card}." : "{user} har omtalt dig i en kommentar på {deck-card}.",
     "The board \"%s\" has been shared with you by %s." : "Tavlen \"%s\" er blevet delt med dig af %s.",
     "{user} has shared {deck-board} with you." : "{user} har delt {deck-board} med dig.",
     "Deck board" : "Opslagstavle",
     "Deck boards, cards and comments" : "Opslagstavler, kort og kommentarer",
     "Create a new deck card" : "Opret et nyt opslagskort",
+    "Card comments" : "Kommentarer på kort",
     "%s on %s" : "%s på %s",
     "Deck boards and cards" : "Opslagstavler og -kort",
     "No data was provided to create an attachment." : "Ingen data blev givet som kunne vedhæftes",
@@ -60,10 +65,11 @@ OC.L10N.register(
     "To review" : "Til gennemgang",
     "Action needed" : "Handling påkrævet",
     "Later" : "Senere",
-    "copy" : "kopier",
+    "copy" : "kopiér",
     "To Do" : "To-do liste",
     "In Progress" : "I gang",
     "Done" : "Afsluttet",
+    "Create your first card!" : "Opret dit første kort!",
     "Attachments" : "Vedhæftede filer",
     "File" : "Fil",
     "Card not found" : "Kort ikke fundet.",
@@ -75,10 +81,12 @@ OC.L10N.register(
     "Select the board to link to a project" : "Vælg tavlen der skal linkes til et projekt",
     "Search by board title" : "Søg efter tavletitel",
     "Select board" : "Vælg tavle",
+    "Move/copy card" : "Flyt/kopiér kort",
     "Select a board" : "Vælg en tavle",
     "No lists available" : "Ingen lister tilgængelige",
     "Select a list" : "Vælg en liste",
     "Move card" : "Flyt kort",
+    "Copy card" : "Kopiér kort",
     "Select the card to link to a project" : "Vælg kortet der skal linkes til et projekt",
     "Link to card" : "Link til kort",
     "Select a card" : "Vælg et kort",
@@ -140,7 +148,7 @@ OC.L10N.register(
     "Add a new card" : "Tilføj et nyt kort",
     "Card name" : "Kortnavn",
     "title and color value must be provided" : "Titel- og farveværdi skal angives.",
-    "Edit" : "Rediger",
+    "Edit" : "Redigér",
     "Add a new tag" : "Opret et nyt tag",
     "Board name" : "Tavlenavn",
     "Members" : "Medlemmer",
@@ -168,17 +176,21 @@ OC.L10N.register(
     "In reply to" : "Som svar til",
     "Cancel reply" : "Annuller svar",
     "Reply" : "Besvar",
-    "Update" : "Opdater",
+    "Update" : "Opdatér",
     "Write a description …" : "Skriv en beskrivelse...",
     "Description" : "Beskrivelse",
     "(Unsaved)" : "(Ikke gemt)",
     "(Saving…)" : "(Gemmer...)",
     "Formatting help" : "Hjælp til formatering",
-    "Edit description" : "Rediger beskrivelse",
+    "Edit description" : "Redigér beskrivelse",
     "View description" : "Se beskrivelse",
     "Add Attachment" : "Tilføj vedhæftning",
     "Choose attachment" : "Vælg en vedhæftning",
     "Select Date" : "Vælg dato",
+    "Later today – {timeLocale}" : "Senere i dag – {timeLocale}",
+    "Tomorrow – {timeLocale}" : "I morgen – {timeLocale}",
+    "This weekend – {timeLocale}" : "Denne weekend – {timeLocale}",
+    "Next week – {timeLocale}" : "Næste uge – {timeLocale}",
     "Set a due date" : "Angiv en forfaldsdato",
     "Remove due date" : "Fjern forfaldsdato",
     "Mark as done" : "Marker som færdig",
@@ -188,9 +200,10 @@ OC.L10N.register(
     "Assign a tag to this card…" : "Tilføj et Tag til dette kort ...",
     "Create a new tag:" : "Opret et nyt tag:",
     "(group)" : "(gruppe)",
+    "Edit card title" : "Redigér titel på kort",
     "Open link" : "Åben link",
     "Card deleted" : "Kort slettet",
-    "Edit title" : "Rediger titel",
+    "Edit title" : "Redigér titel",
     "Assign to me" : "Tildel til mig",
     "Unassign myself" : "Fjern mig selv",
     "Delete card" : "Slet kort",
@@ -200,16 +213,24 @@ OC.L10N.register(
     "Keyboard shortcut" : "Tastaturgenvej",
     "Action" : "Handling",
     "Shift" : "Shift",
+    "Navigate between cards" : "Naviger mellem kort",
+    "Close card details" : "Luk detaljer for kort",
     "Ctrl" : "Ctrl",
     "Search" : "Søg",
+    "Show card filters" : "Vis kort filtre",
+    "Clear card filters" : "Ryd kort filtre",
+    "Card actions" : "Kort handlinger",
     "Enter" : "Indtast",
+    "Open card details" : "Åbn detaljer for kort",
+    "Edit the card title" : "Redigér titel på kort",
+    "Assign yourself to the current card" : "Tilknyt dig selv til det aktuelle kort",
     "All boards" : "Alle tavler",
     "Archived boards" : "Arkiverede lister",
     "Shared with you" : "Delt med dig",
     "Deck settings" : "Opslagsindstillinger",
     "Use bigger card view" : "Brug større kort visning",
     "Show boards in calendar/tasks" : "Vis tavler i kalender/opgaver",
-    "Cancel edit" : "Annuller redigering",
+    "Cancel edit" : "Annullér redigering",
     "Board {0} deleted" : "Tavle {0} er slettet",
     "All cards" : "Alle kort",
     "Only assigned cards" : "Kun tildelte kort",
@@ -217,7 +238,7 @@ OC.L10N.register(
     "An error occurred" : "Der opstod en fejl",
     "Delete the board?" : "Slet tavlen?",
     "Board details" : "Tavledetaljer",
-    "Edit board" : "Rediger liste",
+    "Edit board" : "Redigér liste",
     "Clone board" : "Klon tavle",
     "Unarchive board" : "Genaktiver tavle",
     "Archive board" : "Arkiver tavle",
@@ -234,17 +255,15 @@ OC.L10N.register(
     "Clone due dates" : "Klon forfaldsdatoer",
     "Advanced options" : "Avancerede indstillinger",
     "Clone" : "Klon",
+    "Export {boardTitle}" : "Eksporter {boardTitle}",
     "Export as CSV" : "Eksportér som CSV",
     "Export" : "Eksportér",
     "Loading filtered view" : "Indlæser filtreret visning",
-    "Today" : "I dag",
-    "Tomorrow" : "I morgen",
-    "No due" : "Ikke forfalden",
     "No results found" : "Ingen resultater fundet",
     "Deck board {name}\n* Last modified on {lastMod}" : "Opslagstavle {name}\n* Senest ændret den {lastMod}",
     "Create card" : "Opret kort",
     "Create a new card" : "Opret et nyt kort",
-    "Creating the new card …" : "Oprette det nye kort ...",
+    "Creating the new card …" : "Opretter det nye kort ...",
     "Close" : "Luk",
     "No upcoming cards" : "Ingen kommende kort",
     "upcoming cards" : "kommende kort",
@@ -261,11 +280,14 @@ OC.L10N.register(
     "Share {file} with a Deck card" : "Del {file} med et opslagskort",
     "Share" : "Del",
     "Personal" : "Personligt",
+    "The card \"%s\" on \"%s\" has reached its due date." : "Kortet \"%s\" på \"%s\" har nået sin forfaldsdato.",
     "To do" : "To do",
     "Doing" : "Igang",
     "Example Task 3" : "Eksempel opgave 3",
     "Example Task 2" : "Eksempel opgave 2",
     "Example Task 1" : "Eksempel opgave 1",
-    "Move card to another board" : "Flyt kort til en anden tavle"
+    "Today" : "I dag",
+    "Tomorrow" : "I morgen",
+    "No due" : "Ikke forfalden"
 },
 "nplurals=2; plural=(n != 1);");
