@@ -67,7 +67,6 @@ OC.L10N.register(
     "Upcoming cards" : "Tulevat kortit",
     "Load more" : "Lataa lisää",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Kortti \"%s\" taululla \"%s\" on asetettu sinulle käyttäjän %s toimesta.",
-    "The card \"%s\" on \"%s\" has reached its due date." : "Kortin \"%s\" on \"%s\" eräpäivä on tullut vastaan.",
     "%s has mentioned you in a comment on \"%s\"." : "%s mainitsi sinut kommentissa kortilla \"%s\".",
     "The board \"%s\" has been shared with you by %s." : "Taulu \"%s\" on jaettu kanssasi käyttäjän %s toimesta.",
     "{user} has shared {deck-board} with you." : "{user} on jakanut taulun {deck-board} kanssasi.",
@@ -254,8 +253,6 @@ OC.L10N.register(
     "Clone" : "Kloonaa",
     "Export as CSV" : "Vie CSV:nä",
     "Export" : "Vie",
-    "Today" : "Tänään",
-    "Tomorrow" : "Huomenna",
     "Search for {searchQuery} in all boards" : "Hae ehtoja {searchQuery} kaikilta tauluilta",
     "No results found" : "Ei tuloksia",
     "{nbCards} cards" : "{nbCards} korttia    ",
@@ -282,11 +279,13 @@ OC.L10N.register(
     "Error creating the share" : "Virhe jakoa luotaessa",
     "Share" : "Jaa",
     "Personal" : "Henkilökohtainen",
+    "The card \"%s\" on \"%s\" has reached its due date." : "Kortin \"%s\" on \"%s\" eräpäivä on tullut vastaan.",
     "To do" : "Odottaa",
     "Doing" : "Tekeillä",
     "Example Task 3" : "Esimerkkitehtävä 3",
     "Example Task 2" : "Esimerkkitehtävä 2",
     "Example Task 1" : "Esimerkkitehtävä 1",
-    "Move card to another board" : "Siirrä kortti toiselle taululle"
+    "Today" : "Tänään",
+    "Tomorrow" : "Huomenna"
 },
 "nplurals=2; plural=(n != 1);");
