@@ -79,7 +79,6 @@ OC.L10N.register(
     "Load more" : "Učitaj više",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "Karticu „%s” na „%s” dodijelio vam je %s.",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} vam je dodijelio karticu {deck-card} na {deck-board}.",
-    "The card \"%s\" on \"%s\" has reached its due date." : "Kartica „%s” na „%s” dosegla je datum dospijeća.",
     "The card {deck-card} on {deck-board} has reached its due date." : "Kartica {deck-card} na {deck-board} dosegla je datum dospijeća.",
     "%s has mentioned you in a comment on \"%s\"." : "%s vas spominje u komentaru na „%s”.",
     "{user} has mentioned you in a comment on {deck-card}." : "{user} vas je spomenuo u komentaru na {deck-card}.",
@@ -258,9 +257,6 @@ OC.L10N.register(
     "Clone" : "Kloniraj",
     "Export" : "Izvoz",
     "Loading filtered view" : "Učitavanje filtriranog prikaza",
-    "Today" : "Danas",
-    "Tomorrow" : "Sutra",
-    "No due" : "Nema nezavršenih",
     "Search for {searchQuery} in all boards" : "Traži {searchQuery} na svim pločama",
     "No results found" : "Nema rezultata",
     "{stack} in {board}" : "{stack} u {board}",
@@ -286,11 +282,14 @@ OC.L10N.register(
     "Share {file} with a Deck card" : "Dijeli {file} s Deck karticom",
     "Share" : "Dijeli",
     "Personal" : "Osobno",
+    "The card \"%s\" on \"%s\" has reached its due date." : "Kartica „%s” na „%s” dosegla je datum dospijeća.",
     "To do" : "Zadatak",
     "Doing" : "U postupku",
     "Example Task 3" : "Primjer zadatka 3.",
     "Example Task 2" : "Primjer zadatka 2.",
     "Example Task 1" : "Primjer zadatka 1.",
-    "Move card to another board" : "Premjesti karticu na drugu ploču"
+    "Today" : "Danas",
+    "Tomorrow" : "Sutra",
+    "No due" : "Nema nezavršenih"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
