@@ -1,11 +1,11 @@
 OC.L10N.register(
     "deck",
     {
-    "Personal" : "﻿ವೈಯಕ್ತಿಕ",
-    "Done" : "Done",
     "No file was uploaded" : "ವರ್ಗಾವಣೆಗೆ ﻿ಯಾವುದೇ ಕಡತಗಳು ಕಂಡುಬಂದಿಲ್ಲ",
     "Missing a temporary folder" : "ತಾತ್ಕಾಲಿಕ ಕಡತಕೋಶ ದೊರೆಕುತ್ತಿಲ್ಲ",
+    "Done" : "Done",
     "Cancel" : "﻿ರದ್ದು",
+    "Open" : "ತೆರೆಯಿರಿ",
     "Sharing" : "﻿ಹಂಚಿಕೆ",
     "Can edit" : "Can edit",
     "Can share" : "Can share",
@@ -15,9 +15,12 @@ OC.L10N.register(
     "Download" : "ಪ್ರತಿಯನ್ನು ಸ್ಥಳೀಯವಾಗಿ ಉಳಿಸಿಕೊಳ್ಳಿ",
     "Modified" : "﻿ಬದಲಾಯಿಸಿದ",
     "Save" : "﻿ಉಳಿಸಿ",
+    "Search" : "Search",
     "Shared with you" : "Shared with you",
-    "Today" : "Today",
+    "Export" : "ರಫ್ತು",
     "Close" : "ಮುಚ್ಚು",
-    "Share" : "﻿ಹಂಚಿಕೊಳ್ಳಿ"
+    "Share" : "﻿ಹಂಚಿಕೊಳ್ಳಿ",
+    "Personal" : "﻿ವೈಯಕ್ತಿಕ",
+    "Today" : "Today"
 },
 "nplurals=2; plural=(n > 1);");
