@@ -72,6 +72,18 @@ OC.L10N.register(
     "A <strong>board, list or card</strong> was changed" : "<strong>佈告欄、清單或卡片</strong>已變更",
     "A <strong>comment</strong> was created on a card" : "已在卡片上建立了<strong>留言</strong>",
     "A <strong>card description</strong> has been changed" : "<strong>卡片描述</strong>已變更",
+    "The file was uploaded" : "檔案已上傳",
+    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 選項的限制",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
+    "The file was only partially uploaded" : "檔案僅部份上傳",
+    "No file was uploaded" : "沒有檔案被上傳",
+    "Missing a temporary folder" : "找不到暫存資料夾",
+    "Could not write file to disk" : "無法寫入硬碟",
+    "A PHP extension stopped the file upload" : "一個 PHP 擴充功能終止檔案的上傳",
+    "No file uploaded or file size exceeds maximum of %s" : "沒有上傳檔案或檔案超過上限 %s",
+    "Invalid file type. Only JSON files are allowed." : "無效的檔案類型。僅允許 JSON 檔案。",
+    "Invalid JSON data" : "無效的 JSON 資料",
+    "Failed to import board" : "匯入看板失敗",
     "Cards due today" : "卡片於今日到期",
     "Cards due tomorrow" : "卡片於明日到期",
     "Upcoming cards" : "接下來的卡片",
@@ -79,7 +91,7 @@ OC.L10N.register(
     "Welcome to Nextcloud Deck!" : "歡迎使用 Nextcloud Deck！",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "卡片「%s」位於「%s」已由 %s 分配給您。",
     "{user} has assigned the card {deck-card} on {deck-board} to you." : "{user} 已將位於 {deck-board} 的 {deck-card} 卡片分配給您。",
-    "The card \"%s\" on \"%s\" has reached its due date." : "卡片「%s」位於「%s」已達到期日。",
+    "The card \"%1$s\" on \"%2$s\" has reached its due date." : "在「%2$s」上的卡片「%1$s」已達到期日。",
     "The card {deck-card} on {deck-board} has reached its due date." : "位於 {deck-board} 的 {deck-card} 卡片已達其到期日。",
     "%s has mentioned you in a comment on \"%s\"." : "%s 在「%s」的留言中提到了您。",
     "{user} has mentioned you in a comment on {deck-card}." : "{user} 在 {deck-card} 的留言中提及您。",
@@ -109,23 +121,17 @@ OC.L10N.register(
     "3. Apply rich formatting and link content" : "3. 套用豐富格式與連結內容",
     "4. Share, comment and collaborate!" : "4. 分享、留言與協作！",
     "Create your first card!" : "建立您的第一張卡片！",
-    "The file was uploaded" : "檔案已上傳",
-    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 選項的限制",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
-    "The file was only partially uploaded" : "檔案僅部份上傳",
-    "No file was uploaded" : "沒有檔案被上傳",
-    "Missing a temporary folder" : "找不到暫存資料夾",
-    "Could not write file to disk" : "無法寫入硬碟",
-    "A PHP extension stopped the file upload" : "一個 PHP 擴充功能終止檔案的上傳",
-    "No file uploaded or file size exceeds maximum of %s" : "沒有上傳檔案或檔案超過上限 %s",
     "This comment has more than %s characters.\nAdded as an attachment to the card with name %s.\nAccessible on URL: %s." : "此評論多於 %s 個字元。\n作為附件新增至名為 %s 的卡片上。\n可於此 URL 存取：%s。",
+    "Attachments" : "附件",
+    "File" : "檔案",
+    "date" : "日期",
     "Card not found" : "找不到卡片",
     "Path is already shared with this card" : "路徑已與此卡片分享",
     "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，日期格式必須為 YYYY-MM-DD",
     "Personal planning and team project organization" : "個人規劃與團隊專案組織",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck 是一套看板式組織工具，提供與 Nextcloud 整合的個人規劃與團隊專案組織功能。\n\n\n- 📥 將您的工作項目新增到卡片中，並將它們按順序排列\n- 📄 以 Markdown 編寫額外的註釋\n- 🔖 分配標籤讓組織更方便\n- 👥 與您的團隊、朋友與家人分享\n- 📎 附上檔案並將其嵌入到您的 Markdown 描述中\n- 💬 使用留言與您的團隊討論\n- ⚡ 追蹤活動流程中的變動\n- 🚀 整理好您的專案",
-    "Card details" : "卡片詳細資訊",
     "Add board" : "新增佈告欄",
+    "Card details" : "卡片詳細資訊",
     "Select the board to link to a project" : "選取要連結到專案的佈告欄",
     "Search by board title" : "按佈告欄標題搜尋",
     "Select board" : "選取佈告欄",
@@ -135,17 +141,17 @@ OC.L10N.register(
     "Select a list" : "選取列表",
     "Move card" : "移動卡片",
     "Copy card" : "複製卡片",
-    "Select a card" : "選取卡片",
-    "Cancel" : "取消",
     "Select the card to link to a project" : "選取要連結到專案的卡片",
     "Link to card" : "連結到卡片",
+    "Select a card" : "選取卡片",
+    "Cancel" : "取消",
+    "This board is read only" : "此佈告欄唯讀",
+    "Drop your files to upload" : "拖曳您的檔案以上傳",
     "File already exists" : "檔案已存在",
     "A file with the name {filename} already exists." : "名稱為 {filename} 的檔案已存在。",
     "Do you want to overwrite it?" : "您想要覆寫它嗎？",
     "Overwrite file" : "覆寫檔案",
     "Keep existing file" : "保留既有檔案",
-    "This board is read only" : "此佈告欄唯讀",
-    "Drop your files to upload" : "拖曳您的檔案以上傳",
     "Add card" : "新增卡片",
     "Archived cards" : "已封存的卡片",
     "Add list" : "新增列表",
@@ -186,6 +192,12 @@ OC.L10N.register(
     "Deleted lists" : "已刪除的列表",
     "Undo" : "復原",
     "Deleted cards" : "已刪除的卡片",
+    "Failed to create share with {displayName}" : "無法建立與 {displayName} 的分享",
+    "Are you sure you want to transfer the board {title} to {user}?" : "您確定您想要將看板 {title} 轉移給 {user} 嗎？",
+    "Transfer the board." : "轉移看板。",
+    "Transfer" : "轉移",
+    "The board has been transferred to {user}" : "看板已轉移給 {user}",
+    "Failed to transfer the board to {user}" : "轉移看板給 {user} 失敗",
     "Share board with a user, group or team …" : "與使用者、群組或團隊分享佈告欄……",
     "Searching for users, groups and teams …" : "搜尋使用者、群組與團隊……",
     "No participants found" : "找不到參與者",
@@ -197,12 +209,7 @@ OC.L10N.register(
     "Can manage" : "可以管理",
     "Owner" : "擁有者",
     "Delete" : "刪除",
-    "Failed to create share with {displayName}" : "無法建立與 {displayName} 的分享",
-    "Are you sure you want to transfer the board {title} to {user}?" : "您確定您想要將看板 {title} 轉移給 {user} 嗎？",
-    "Transfer the board." : "轉移看板。",
-    "Transfer" : "轉移",
-    "The board has been transferred to {user}" : "看板已轉移給 {user}",
-    "Failed to transfer the board to {user}" : "轉移看板給 {user} 失敗",
+    "List deleted" : "列表已刪除",
     "Edit list title" : "編輯清單標題",
     "Archive all cards" : "封存所有卡片",
     "Unarchive all cards" : "解除封存所有卡片",
@@ -211,15 +218,16 @@ OC.L10N.register(
     "Unarchive all cards in this list" : "解除封存所有此列表中的卡片",
     "Add a new card" : "新增卡片",
     "Card name" : "卡片名稱",
-    "List deleted" : "列表已刪除",
+    "title and color value must be provided" : "必須提供標題與顏色的值",
     "Edit" : "編輯",
     "Add a new tag" : "新增標籤",
-    "title and color value must be provided" : "必須提供標題與顏色的值",
     "Board name" : "佈告欄名稱",
     "Members" : "成員",
     "Assign to users/groups/team" : "分配給使用者／群組／團隊",
     "Assign a user to this card…" : "分配使用者到此卡片……",
     "Select a user to assign to this card…" : "選取要分配至此卡片的使用者……",
+    "File to share" : "要分享的檔案",
+    "Invalid path selected" : "選取的路徑無效",
     "Upload new files" : "上傳新檔案",
     "Share from Files" : "從「檔案」分享",
     "Pending share" : "待分享",
@@ -229,25 +237,25 @@ OC.L10N.register(
     "Remove attachment" : "移除附件",
     "Delete Attachment" : "刪除附件",
     "Restore Attachment" : "還原附件",
-    "File to share" : "要分享的檔案",
-    "Invalid path selected" : "選取的路徑無效",
-    "Open in sidebar view" : "在側邊欄中開啟",
-    "Open in bigger view" : "以較大的檢視模式開啟",
-    "Attachments" : "附件",
-    "Comments" : "留言",
     "Modified" : "已修改",
     "Created" : "已新增",
     "The title cannot be empty." : "標題不能為空",
-    "No comments yet. Begin the discussion!" : "暫無留言。開始討論吧！",
+    "Cannot close unsaved card!" : "無法關閉無法儲存的卡片！",
+    "Open in sidebar view" : "在側邊欄中開啟",
+    "Open in bigger view" : "以較大的檢視模式開啟",
+    "Comments" : "留言",
     "Failed to load comments" : "載入留言失敗",
-    "Save" : "儲存",
+    "No comments yet. Begin the discussion!" : "暫無留言。開始討論吧！",
     "The comment cannot be empty." : "留言不能為空。",
     "The comment cannot be longer than 1000 characters." : "留言不能多於 1000 個字元。",
+    "Save" : "儲存",
+    "Created:" : "建立：",
     "In reply to" : "回覆",
     "Cancel reply" : "取消回覆",
     "Reply" : "回覆",
     "Update" : "更新",
-    "Created:" : "建立：",
+    "Write a description …" : "編寫描述……",
+    "Could not save description" : "無法儲存描述",
     "Description" : "描述",
     "(Unsaved)" : "（未儲存）",
     "(Saving…)" : "（正在儲存……）",
@@ -255,8 +263,16 @@ OC.L10N.register(
     "Edit description" : "編輯描述",
     "View description" : "檢視描述",
     "Add Attachment" : "新增附件",
-    "Write a description …" : "編寫描述……",
     "Choose attachment" : "選擇附件",
+    "Select Date" : "選擇日期",
+    "Later today – {timeLocale}" : "今天稍後 – {timeLocale}",
+    "Set due date for later today" : "設定今天稍後的到期日",
+    "Tomorrow – {timeLocale}" : "明天 – {timeLocale}",
+    "Set due date for tomorrow" : "設定明天的到期日",
+    "This weekend – {timeLocale}" : "本週末 – {timeLocale}",
+    "Set due date for this weekend" : "設定本週末的到期日",
+    "Next week – {timeLocale}" : "下週 – {timeLocale}",
+    "Set due date for next week" : "設定下週的到期日",
     "Assign a due date to this card…" : "為此卡片指派到期日……",
     "Set a due date" : "設定到期日",
     "Add due date" : "新增到期日",
@@ -267,26 +283,20 @@ OC.L10N.register(
     "Not done" : "未完成",
     "Unarchive card" : "解除封存卡片",
     "Archive card" : "封存卡片",
-    "Select Date" : "選擇日期",
-    "Set due date for later today" : "設定今天稍後的到期日",
-    "Set due date for tomorrow" : "設定明天的到期日",
-    "Set due date for this weekend" : "設定本週末的到期日",
-    "Set due date for next week" : "設定下週的到期日",
     "Assign a tag to this card…" : "分配標籤到此卡片……",
     "Select or create a tag…" : "選取或建立標籤……",
     "Create a new tag:" : "建立新標籤：",
     "(group)" : "（群組）",
-    "Next week – {timeLocale}" : "下週 – {timeLocale}",
-    "Todo items" : "待辦事項",
     "{count} comments, {unread} unread" : "{count} 則留言，{unread} 則未讀",
+    "Todo items" : "待辦事項",
     "Edit card title" : "編輯卡片標題",
     "Open link" : "開啟連結",
+    "Card deleted" : "卡片已刪除",
     "Edit title" : "編輯標題",
     "Assign to me" : "分配給我",
     "Unassign myself" : "取消分配給我",
     "Mark as not done" : "標記為未完成",
     "Delete card" : "刪除卡片",
-    "Card deleted" : "卡片已刪除",
     "seconds ago" : "幾秒前",
     "Keyboard shortcuts" : "鍵盤快速鍵",
     "Boost your productivity using Deck with keyboard shortcuts." : "在 Deck 上利用鍵盤快捷鍵提高您的生產力。",
@@ -325,6 +335,14 @@ OC.L10N.register(
     "Users outside of those groups will not be able to create their own boards, but will still be able to work on boards that have been shared with them." : "這些群組以外的使用者將無法建立自己的看板，但仍然可以在與他們分享的看板上工作。",
     "Cancel edit" : "取消編輯",
     "Save board" : "儲存佈告欄",
+    "Board {0} deleted" : "已刪除佈告欄 {0}",
+    "All cards" : "所有看片",
+    "Only assigned cards" : "僅已分配的卡片",
+    "No reminder" : "無提醒",
+    "An error occurred" : "發生錯誤",
+    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "您確定要刪除佈告欄 {title} 嗎？這將會刪除所有此佈告欄的資料，包含封存的卡片。",
+    "Delete the board?" : "刪除佈告欄？",
+    "Exporting board..." : "正在匯出看板……",
     "Board details" : "佈告欄詳細資訊",
     "Edit board" : "編輯佈告欄",
     "Clone board" : "再製佈告欄",
@@ -334,16 +352,12 @@ OC.L10N.register(
     "Turn on due date reminders" : "開啟到期日提醒",
     "Turn off due date reminders" : "關閉到期日提醒",
     "Due date reminders" : "到期日提醒",
-    "All cards" : "所有看片",
     "Assigned cards" : "已分配的卡片",
     "No notifications" : "無通知",
     "Delete board" : "刪除佈告欄",
-    "Board {0} deleted" : "已刪除佈告欄 {0}",
-    "Only assigned cards" : "僅已分配的卡片",
-    "No reminder" : "無提醒",
-    "An error occurred" : "發生錯誤",
-    "Are you sure you want to delete the board {title}? This will delete all the data of this board including archived cards." : "您確定要刪除佈告欄 {title} 嗎？這將會刪除所有此佈告欄的資料，包含封存的卡片。",
-    "Delete the board?" : "刪除佈告欄？",
+    "Importing board..." : "正在匯入看板……",
+    "Board imported successfully" : "已成功匯入看板",
+    "Import board" : "匯入看板",
     "Clone {boardTitle}" : "再製 {boardTitle}",
     "Clone cards" : "複製卡片",
     "Clone assignments" : "再製工作",
@@ -353,21 +367,25 @@ OC.L10N.register(
     "Move all cards to the first list" : "將所有卡片移動到第一個清單",
     "Restore archived cards" : "還原已封存的卡片",
     "Clone" : "複製",
+    "Export {boardTitle}" : "匯出 {boardTitle}",
+    "Export as JSON" : "匯出為 JSON",
+    "Export as CSV" : "匯出為 CSV",
+    "Note: Only the JSON format is supported for importing back into the Deck app." : "注意：匯入回 Deck 應用程式時僅支援 JSON 格式。",
+    "Export" : "匯出",
     "Loading filtered view" : "正在載入過濾的檢視",
-    "Today" : "今天",
-    "Tomorrow" : "明天",
-    "No due" : "無到期日",
+    "Search for {searchQuery} in other boards" : "在其他看板中搜尋 {searchQuery}",
     "Search for {searchQuery} in all boards" : "在所有佈告欄中搜尋 {searchQuery}",
     "No results found" : "找不到結果",
     "Deck board {name}\n* Last modified on {lastMod}" : "Deck 看板 {name}\n* 最後修改於 {lastMod}",
-    "{stack} in {board}" : "{stack} 於 {board}",
-    "Click to expand description" : "點擊展開描述",
     "* Created on {created}\n* Last modified on {lastMod}\n* {nbAttachments} attachments\n* {nbComments} comments" : "* 建立於 {created}\n* 最後修改於 {lastMod}\n* {nbAttachments} 個附件\n* {nbComments} 則留言",
     "{nbCards} cards" : "{nbCards} 張卡片",
+    "Due on {date}" : "於 {date} 到期",
+    "{stack} in {board}" : "{stack} 於 {board}",
+    "Click to expand description" : "點擊展開描述",
     "Click to expand comment" : "點擊展開留言",
+    "Create card" : "建立卡片",
     "Create a new card" : "建立新卡片",
     "Card title" : "卡片標題",
-    "Create card" : "建立卡片",
     "Creating the new card …" : "正在建立新卡片……",
     "Card \"{card}\" was added to \"{board}\"" : "卡片「{card}」已新增至「{board}」",
     "Open card" : "開啟卡片",
@@ -377,10 +395,6 @@ OC.L10N.register(
     "upcoming cards tomorrow" : "明天接下來的卡片",
     "upcoming cards" : "接下來的卡片",
     "New card" : "新卡片",
-    "Due on {date}" : "於 {date} 到期",
-    "This weekend – {timeLocale}" : "本週末 – {timeLocale}",
-    "Tomorrow – {timeLocale}" : "明天 – {timeLocale}",
-    "Later today – {timeLocale}" : "今天稍後 – {timeLocale}",
     "Link to a board" : "連結到佈告欄",
     "Link to a card" : "連結到卡片",
     "Create a card" : "建立卡片",
@@ -388,17 +402,21 @@ OC.L10N.register(
     "Something went wrong" : "出了點問題",
     "Failed to upload {name}" : "上傳 {name} 失敗",
     "Maximum file size of {size} exceeded" : "超過最大的檔案大小 {size} ",
+    "Assigned users" : "已分派的使用者 ",
+    "Due date" : "到期日",
     "Error creating the share" : "建立分享時發生錯誤",
     "Share with a Deck card" : "與 Deck 卡片分享",
     "Share {file} with a Deck card" : "與 Deck 卡片分享 {file}",
     "Share" : "分享",
     "Personal" : "個人",
+    "The card \"%s\" on \"%s\" has reached its due date." : "卡片「%s」位於「%s」已達到期日。",
     "To do" : "待辦事項",
     "Doing" : "正在進行",
     "Example Task 3" : "範例工作 3",
     "Example Task 2" : "範例工作 2",
     "Example Task 1" : "範例工作 1",
-    "Move card to another board" : "將卡片移動到其他佈告欄",
-    "Filter by completed" : "按已完成篩選"
+    "Today" : "今天",
+    "Tomorrow" : "明天",
+    "No due" : "無到期日"
 },
 "nplurals=1; plural=0;");
