@@ -1,24 +1,8 @@
 <?php
+
 /**
- * @copyright Copyright (c) 2021 Vitor Mattos <vitor@php.rio>
- *
- * @author Vitor Mattos <vitor@php.rio>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Deck\Command;
@@ -32,7 +16,7 @@ use Symfony\Component\Console\Output\OutputInterface;
 
 class BoardImport extends Command {
 	public function __construct(
-		private BoardImportCommandService $boardImportCommandService
+		private BoardImportCommandService $boardImportCommandService,
 	) {
 		parent::__construct();
 	}
@@ -60,12 +44,12 @@ class BoardImport extends Command {
 				null,
 				InputOption::VALUE_REQUIRED,
 				'Configuration json file.',
-				'config.json'
+				null
 			)
 			->addOption(
 				'data',
 				null,
-				InputOption::VALUE_OPTIONAL,
+				InputOption::VALUE_REQUIRED,
 				'Data file to import.',
 				'data.json'
 			)
